@@ -7,51 +7,36 @@ Created on Thu Jun 20 13:56:19 2019
 """
 import numpy as np
 def figsize(scale):
-
     fig_width_pt = 469.755                          # Get this from LaTeX using \the\textwidth
-
     inches_per_pt = 1.0/72.27                       # Convert pt to inch
-
     golden_mean = (np.sqrt(5.0)-1)/2.0              # Aesthetic ratio (you could change this)
-
     fig_width = fig_width_pt*inches_per_pt*scale    # width in inches
-
     fig_height = fig_width*golden_mean              # height in inches
-
     fig_size = [fig_width,fig_height]               # reverse widht and height for horizontal plots
-
     return fig_size
 
 pgf_with_latex = {                      # setup matplotlib to use latex for output
-                  
     "pgf.texsystem": "pdflatex",        # change this if using xetex or lautex
-
     "text.usetex": True,                # use LaTeX to write all text
-
     "font.family": "serif",
-
     "font.serif": [],                   # blank entries should cause plots to inherit fonts from the document
-
     "font.sans-serif": [],
-
     "font.monospace": [],
-
-    "axes.labelsize": 16,                # LaTeX default is 10pt font.     "text.fontsize": 10,
-    
+    "axes.labelsize": 16,                # LaTeX default is 10pt font.     "text.fontsize": 10, 
     "axes.linewidth": 2,                
-
-    "legend.fontsize": 'small',               # Make the legend/label fonts a little smaller
-
-    "xtick.labelsize": 16,
-
+    "legend.fontsize": 16,               # Make the legend/label fonts a little smaller
     "ytick.labelsize": 16,
-
+    "ytick.major.width": 2,
+    "ytick.major.size": 6,
+    "ytick.direction": "in",
+    "ytick.labelsize": 16,
+    "xtick.labelsize": 16,
+    "xtick.major.size": 6,
+    "xtick.major.width": 2,
+    "xtick.direction": "in",            
     "figure.figsize": figsize(1.4),       # default fig size of 0.9 textwidth
-
     "pgf.preamble": [
-
         r"\usepackage[utf8x]{inputenc}",    # use utf8 fonts becasue your computer can handle it :)
-
         r"\usepackage[T1]{fontenc}",        # plots will be generated using this preamble
         ]
     }
@@ -79,6 +64,7 @@ plt.ion()
 
 
 def save_proj(x,y,ytot,convolution, k,freq,n,namedir, params, max_Z):
+    pgf_with_latex["figure.figsize"] = figsize(1.4)
     mpl.rcParams.update(pgf_with_latex)
 
     name_current_dir = namedir+'/'+str(k)
@@ -209,18 +195,18 @@ def plot_k2(kk, kk_many, frequencies_disp, frequencies_ft, f, data, data_project
     kk_many = kk_many/kk_many[-1]
     kk = kk/kk[-1]
     
-    fig, ax = plt.subplots()
-#    if(len(branches) == tot_branches): #plot whole spectrum
-#        if(max_Z > np.max(data) or max_Z < 0.0):
-#            max_Z = np.max(data)
-#        print('Drawing the whole spectrum...')
-#        ax.contourf(X,Y,data,100, vmax=max_Z)
-#        print('finished')
     if(max_Z > np.max(data_projected) or max_Z < 0.0):
         max_Z = np.max(data_projected)
-    print('Drawing branches ', branches)
-    ax.pcolormesh(X,Y,np.sum(data_projected[:,branches,:], axis=1), vmax=max_Z, cmap='Blues')
-    print('finished')
+    
+    fig, ax = plt.subplots()
+    if(len(branches) == tot_branches): #plot whole spectrum
+        print('Drawing the whole spectrum...')
+        ax.pcolormesh(X,Y,data, vmax=max_Z, cmap='Blues')
+        print('finished')
+    else:
+        print('Drawing branches ', branches)
+        ax.pcolormesh(X,Y,np.sum(data_projected[:,branches,:], axis=1), vmax=max_Z, cmap='Blues')
+        print('finished')
     
     
     ax2 = plt.twinx()
@@ -250,7 +236,6 @@ def plot_k2(kk, kk_many, frequencies_disp, frequencies_ft, f, data, data_project
 
 def plot1(freq,ZQS, labels):
     pgf_with_latex["figure.figsize"] = figsize(1.4)[::-1]
-
     mpl.rcParams.update(pgf_with_latex)
     n = len(ZQS[0])-1
 
@@ -262,13 +247,7 @@ def plot1(freq,ZQS, labels):
         axs[i].text(.75,.75,labels[i],fontsize=12,horizontalalignment='center', verticalalignment='center',transform=axs[i].transAxes)
         axs[i].plot(freq, ZQS[:,i+1])
     
-    axs[0].tick_params(axis='x', which='major', labelsize=15, width=2 , length=6, direction='in', top = True, bottom=False)
-    axs[-1].tick_params(axis='x', which='major', labelsize=15, width=2 , length=6, direction='in', bottom = True)
-    plt.rcParams['axes.linewidth'] = 2
     plt.yticks([])
-    plt.yticks([])
-#    fig.add_subplot(111, frameon=False)
-#    plt.tick_params(labelcolor='none', top=False, bottom=False, left=False, right=False)
 #    plt.ylabel('K-point DOS [kB T * ps]')
     plt.xlabel('Frequency [Thz]')
     plt.tight_layout()
@@ -293,21 +272,17 @@ def plot2(freq,ZQS,modes, labels, freqs_from_disp):
             axs[i].text(.75,.75,labels[n]+str('\n mode')+str(mode),fontsize=12,horizontalalignment='center', verticalalignment='center',transform=axs[i].transAxes)
             axs[i].plot(freq, ZQS[n,:,mode+1])
 
-        axs[0].tick_params(axis='x', which='major', labelsize=15, width=2 , length=6, direction='in', top = True, bottom=False)
-        axs[-1].tick_params(axis='x', which='major', labelsize=15, width=2 , length=6, direction='in', bottom = True)
         plt.yticks([])
-#        fig.add_subplot(111, frameon=False)
-#        plt.tick_params(labelcolor='none', top=False, bottom=False, left=False, right=False)
 #        plt.ylabel('K-point DOS [kB T * ps]')
         plt.xlabel('Frequency [Thz]')
 #        plt.tight_layout()
-        
         plt.show() 
         fig.savefig('plot2_'+str(n)+'.pdf')
     return
 
 
 def plot3(Ts, frequencies, modes, labels):
+    pgf_with_latex["figure.figsize"] = figsize(1.4)
     mpl.rcParams.update(pgf_with_latex)
     n_kpoints = len(frequencies[0,0,:,0])
     markers = ['s','o','v','X','+','.','^','<','>','*','s','o','v','X','+','.','^','<','>','*']
@@ -335,8 +310,9 @@ def plot3(Ts, frequencies, modes, labels):
 
 def plot40(kk, kk_many, frequencies, frequencies_disp, frequencies_ft, qpoints, x_labels, ZQS, DOS_0K, interp):
     """
-    old plot 4, with mathematical interpolation
+    new plot 4, with real interpolation
     """
+    pgf_with_latex["figure.figsize"] = figsize(1.4)
     mpl.rcParams.update(pgf_with_latex)
     freq = ZQS[:,0] 
     fig = plt.figure()
@@ -358,7 +334,6 @@ def plot40(kk, kk_many, frequencies, frequencies_disp, frequencies_ft, qpoints,
     ax.set_xticks(kk, x_labels.tolist())
     ax.legend(handles=[graph_disp, graph_MD])
     ax.set_ylabel('Frequency [Thz]')
-    ax.tick_params(axis='both', which='major', labelsize=15, width=2 , length=6, direction='in', top=True, right=True)
     ax.axhline(0, linestyle='--', color='b')
     
     ax2.plot(DOS_0K[:,1], DOS_0K[:,0], c='black', linewidth=1)
@@ -378,6 +353,7 @@ def plot4(kk, kk_MD, frequencies, frequencies_disp, x_labels, DOS_info):
     """
     new plot 4, with real interpolation
     """
+    pgf_with_latex["figure.figsize"] = figsize(1.4)
     mpl.rcParams.update(pgf_with_latex)
     # freq = ZQS[:,0] 
     fig = plt.figure()
@@ -400,7 +376,6 @@ def plot4(kk, kk_MD, frequencies, frequencies_disp, x_labels, DOS_info):
 
     
     ax.set_ylabel('Frequency [Thz]')
-    ax.tick_params(axis='both', which='major', labelsize=12, width=2 , length=6, direction='in', top=True, right=True)
     ax.axhline(0, linestyle='--', color='b')
     ax.legend(handles=[graph_disp, graph_ft])
 
@@ -409,10 +384,8 @@ def plot4(kk, kk_MD, frequencies, frequencies_disp, x_labels, DOS_info):
     graph_DOS_finiteK,= ax2.plot(DOS_ft,freq_DOS, c='red', label = 'finte K DOS')
 
     ax2.set_xticks([])
-    ax2.tick_params(axis='y', which='major', labelsize=0.0000001, width=2 , length=6, direction='in', top=True, right=True)
     ax2.legend()
     
-    
     plt.show()
     fig.savefig('plot4.pdf', backend='pgf')
     return
