@@ -58,10 +58,7 @@ if(plot_type==0):
         
         # harmonic things
         D = util.get_D(k, K,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
-        eigvals = np.linalg.eigvalsh(D)
-        idx = np.argsort(eigvals)
-        eigvals = eigvals[idx]
-        omegas = np.sqrt(eigvals)/2/np.pi
+        eigvals, omegas = util.get_eigvals(D)
 
         freq_disp = omegas
         print(' Creating plots for k point = ', k_scaled)
@@ -73,8 +70,9 @@ if(plot_type==0):
                 sig, mi = (freq[1]-freq[0]), (freq[-1]-freq[0])/2
             else:
                 sig, mi = gaussian_smoothing, (freq[-1]-freq[0])/2
+            if(sig==0 or sig==0.0):
+                sig = freq[1]-freq[0]
             
-
             gaussian = util.norm_gaussian(freq, mi, sig)                
             # convolution_lorentzian = signal.fftconvolve(Z[:,n], plot.lorentzian(freq, freq[int(len(freq)/2)], params[1], params[2]), mode='same') / sum( plot.lorentzian(freq, *params))
             convolution = signal.fftconvolve(Z[:,n],gaussian, mode='same') / sum( gaussian)
@@ -101,7 +99,7 @@ if(plot_type==1):
                 
                 sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
                 if(sig<=0):
-                    sig = 0.0001
+                    sig = freq[1]-freq[0]
 
                 gaussian = util.norm_gaussian(freq, mi, sig)                
                 # convolution_lorentzian = signal.fftconvolve(Z[:,n], plot.lorentzian(freq, freq[int(len(freq)/2)], params[1], params[2]), mode='same') / sum( plot.lorentzian(freq, *params))
@@ -137,10 +135,7 @@ if(plot_type==2):
                 accepted_labels.append(labels[j])
                 # harmonic things
                 D = util.get_D(k, K,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
-                eigvals = np.linalg.eigvalsh(D)
-                idx = np.argsort(eigvals)
-                eigvals = eigvals[idx]
-                omegas = np.sqrt(eigvals)/2/np.pi
+                eigvals, omegas = util.get_eigvals(D)
 
                 for m in range(Nqs_path):
                     if(np.allclose(qpoint,ks_scaled_path[m])):
@@ -152,11 +147,11 @@ if(plot_type==2):
                     params = Params[:,n]
                     if(gaussian_smoothing != 0):
                         if(gaussian_smoothing < 0):
-                            sig, mi = params[-1]/2, freq[int(len(freq)/2)]
+                            sig, mi = params[-1]/2.355, freq[int(len(freq)/2)]
                     else:
                         sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
                     if(sig==0):
-                        sig = 0.0001
+                        sig = freq[1]-freq[0]
     
                     gaussian = util.norm_gaussian(freq, mi, sig)                
                     # convolution_lorentzian = signal.fftconvolve(Z[:,n], plot.lorentzian(freq, freq[int(len(freq)/2)], params[1], params[2]), mode='same') / sum( plot.lorentzian(freq, *params))
@@ -227,6 +222,8 @@ if(plot_type==4):
         eigvals_0K, omegas_0K = util.get_eigvals(D_0K)
 
         sigma = gaussian_smoothing
+        if (sigma == 0 or sigma == 0.0):
+            sigma = freq_DOS[1] - freq_DOS[0]
         DOS = DOS + np.sum(util.norm_gaussian(freq_DOS,omegas_0K,sigma), axis=1)*weight/(3*tot_atoms_uc*N1N2N3_k*2)
         DOS_renorm = DOS_renorm + np.sum(util.norm_gaussian(freq_DOS,omegas_renorm,sigma), axis=1)*weight/(3*tot_atoms_uc*N1N2N3_k*2)
     DOS_info = np.vstack((freq_DOS, DOS, DOS_renorm)).T
@@ -288,7 +285,7 @@ if(plot_type==40):
             print('automatic sigma not allowed in this mode, sigma set to 0.1')
             sig, mi = 0.1, freq[int(len(freq)/2)]
     else:
-        sig, mi = 0.001, freq[int(len(freq)/2)]
+        sig, mi = freq[1]-freq[0], freq[int(len(freq)/2)]
     
     # take the path the user inputs and find all the k points you can plot
     ks_scal_path_many, ks_path_many, distances = util.get_kpath_many(ks_scaled_path, Hk, npoints=interp+1)
@@ -453,24 +450,33 @@ if(plot_type==5):
                 accepted_qpoints.append(qpoint.tolist())
                 
                 Zq = np.genfromtxt(prefix+'Zqs'+appendix,skip_header=to_skip+1, max_rows=meta)
-                ZQS[:,count] = Zq[:,0]
-                for b in range(tot_atoms_uc*3):
-                    params = Params[:,b]
-
-                    if(gaussian_smoothing != 0):
-                        if(gaussian_smoothing < 0):
-                            sig, mi = params[-1]/2, freq[int(len(freq)/2)]
-                            if (sig == 0):
-                                sig = 0.0001
-                        else:
-                            sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
-                        
+                # case 1
+                if(gaussian_smoothing < 0):   
+                    for b in range(tot_atoms_uc*3):
+                        params = Params[:,b]
+                        sig, mi = params[-1]/2.355, freq[int(len(freq)/2)]
+                        if( sig <= freq[1]-freq[0]):
+                            sig = freq[1]-freq[0]
                         gaussian = util.norm_gaussian(freq, mi, sig)
                         convolution = signal.fftconvolve(Zq[:,b+1],gaussian, mode='same') / sum( gaussian)
                         ZQS_proj[:,b,i] = convolution
-                    else:
+                    ZQS[:,count] = np.sum(ZQS_proj[:,:,i],axis=1)
+                # case 2   
+                elif(gaussian_smoothing > 0):
+                    sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
+                    gaussian = util.norm_gaussian(freq, mi, sig)
+                    for b in range(tot_atoms_uc*3):
+                        convolution = signal.fftconvolve(Zq[:,b+1],gaussian, mode='same') / sum( gaussian)
+                        ZQS_proj[:,b,i] = convolution
+                    convolution_q = signal.fftconvolve(Zq[:,0],gaussian, mode='same') / sum( gaussian)
+                    ZQS[:,count] = convolution_q
+                # case 3     
+                else:
+                    for b in range(tot_atoms_uc*3):
                         ZQS_proj[:,b,i] = Zq[:,b+1]
-        count = count + 1
+                    ZQS[:,count] = Zq[:,0]
+                count = count + 1
+                        
 # =============================================================================      
 
 
@@ -478,9 +484,6 @@ if(plot_type==5):
     indexes, freqs_reshaped = util.get_real_branches(frequencies, EIGVECS_0K, masses_uc, ks_path_many)
     indexes_0K, freqs_disp_reshaped = util.get_real_branches(frequencies_disp, EIGVECS_0K, masses_uc, ks_path_many)
     
-    # #this is to reshape spectra according to real branches
-    # indexes, freqs_disp_reshaped = util.aaa_get_real_branches(frequencies_disp, EIGVECS_0K, masses_uc, Hk, ks_scal_path_many)
-    
     frequencies_reshaped, frequencies_disp_reshaped  = np.copy(frequencies), np.copy(frequencies_disp)
     frequencies_reshaped, frequencies_disp_reshaped = freqs_reshaped, freqs_disp_reshaped
     
@@ -493,11 +496,7 @@ if(plot_type==5):
         ZQS_proj_interp = util.interpol_spectrum(ks_path, freq, freqs_from_spectrum, distances_comm, distances_many, frequencies_reshaped, EIGVECS_0K, modes, ZQS_proj_reshaped)
     else:
         ZQS_proj_interp = ZQS_proj_reshaped[:,:,:]
-        
-    # if (interp>0):
-    #     ZQS_proj_interp = util.aaa_interpol_spectrum(ks_path, freq, freqs_from_spectrum, EIGVECS_0K, modes, ZQS_proj_reshaped, interp)
-    # else:
-    #     ZQS_proj_interp = ZQS_proj_reshaped[:,range(len(modes)),:]
+
         
     plot.plot_k2(distances_comm, distances_many, frequencies_disp_reshaped, frequencies_reshaped, freq,ZQS,ZQS_proj_interp, x_labels,max_Z,modes)
 
